.. _fanc-architecture:

=================================
FAN-C Python architecture modules
=================================

.. toctree::
   :maxdepth: 1

   aggregate <architecture/aggregate>
   comparisons <architecture/comparisons>
   compartments <architecture/compartments>
   domains <architecture/domains>
